## $Id: interfaces.py 14995 2018-04-27 07:35:05Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""Customized interfaces of the university application package.
"""

from zope import schema
from waeup.kofa.applicants.interfaces import (
    IApplicantBaseData,
    AppCatCertificateSource, CertificateSource)
from waeup.kofa.schoolgrades import ResultEntryField
from waeup.kofa.interfaces import (
    SimpleKofaVocabulary, academic_sessions_vocab, validate_email)
from waeup.kofa.schema import FormattedDate, TextLineChoice
from waeup.kofa.students.vocabularies import nats_vocab, GenderSource
from waeup.kofa.applicants.interfaces import contextual_reg_num_source
from kofacustom.nigeria.applicants.interfaces import (
    LGASource, high_qual, high_grade, exam_types,
    INigeriaUGApplicant, INigeriaPGApplicant,
    INigeriaApplicantOnlinePayment,
    INigeriaUGApplicantEdit, INigeriaPGApplicantEdit,
    INigeriaApplicantUpdateByRegNo,
    IPUTMEApplicantEdit,
    )
from kofacustom.esitm.interfaces import MessageFactory as _
from kofacustom.esitm.payments.interfaces import ICustomOnlinePayment

class ICustomUGApplicant(INigeriaUGApplicant):
    """An undergraduate applicant.

    This interface defines the least common multiple of all fields
    in ug application forms. In customized forms, fields can be excluded by
    adding them to the UG_OMIT* tuples.
    """

class ICustomPGApplicant(INigeriaPGApplicant):
    """A postgraduate applicant.

    This interface defines the least common multiple of all fields
    in pg application forms. In customized forms, fields can be excluded by
    adding them to the PG_OMIT* tuples.
    """


class ICustomApplicant(ICustomUGApplicant, ICustomPGApplicant):
    """An interface for both types of applicants.

    Attention: The ICustomPGApplicant field seetings will be overwritten
    by ICustomPGApplicant field settings. If a field is defined
    in both interfaces zope.schema validates only against the
    constraints in ICustomUGApplicant. This does not affect the forms
    since they are build on either ICustomUGApplicant or ICustomPGApplicant.
    """

    def writeLogMessage(view, comment):
        """Adds an INFO message to the log file
        """

    def createStudent():
        """Create a student object from applicant data
        and copy applicant object.
        """

class ICustomUGApplicantEdit(INigeriaUGApplicantEdit):
    """An undergraduate applicant interface for edit forms.

    Here we can repeat the fields from base data and set the
    `required` and `readonly` attributes to True to further restrict
    the data access. Or we can allow only certain certificates to be
    selected by choosing the appropriate source.

    We cannot omit fields here. This has to be done in the
    respective form page.
    """

class ICustomPGApplicantEdit(INigeriaPGApplicantEdit):
    """A postgraduate applicant interface for editing.

    Here we can repeat the fields from base data and set the
    `required` and `readonly` attributes to True to further restrict
    the data access. Or we can allow only certain certificates to be
    selected by choosing the appropriate source.

    We cannot omit fields here. This has to be done in the
    respective form page.
    """

class ICustomApplicantOnlinePayment(INigeriaApplicantOnlinePayment):
    """An applicant payment via payment gateways.

    """

class IPUTMEApplicantEdit(IPUTMEApplicantEdit):
    """An undergraduate applicant interface for editing.

    Here we can repeat the fields from base data and set the
    `required` and `readonly` attributes to True to further restrict
    the data access. Or we can allow only certain certificates to be
    selected by choosing the appropriate source.

    We cannot omit fields here. This has to be done in the
    respective form page.
    """

class ICustomApplicantUpdateByRegNo(INigeriaApplicantUpdateByRegNo):
    """Representation of an applicant.

    Skip regular reg_number validation if reg_number is used for finding
    the applicant object.
    """
